@@ -1,7 +1,8 @@
 from typing import Any, Optional
 from enum import Enum, IntEnum
-from pydantic import BaseModel, Field, validator
-from custom_exceptions import InvalidMovesException
+from pydantic import BaseModel, validator
+
+from .custom_exceptions import InvalidMovesException
 
 
 class Piece(str, Enum):
